// nav.hxx -- vor/dme/ndb class
//
// Written by Curtis Olson, started April 2000.
//
// Copyright (C) 2000  Curtis L. Olson - curt@flightgear.org
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation; either version 2 of the
// License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//
// $Id: nav.hxx,v 1.6 2000/05/12 20:17:10 curt Exp $


#ifndef _FG_NAV_HXX
#define _FG_NAV_HXX


#include <simgear/compiler.h>
#include <simgear/math/fg_geodesy.hxx>
#include <simgear/misc/fgstream.hxx>

#ifdef FG_HAVE_STD_INCLUDES
#  include <istream>
#elif defined( FG_HAVE_NATIVE_SGI_COMPILERS )
#  include <iostream.h>
#elif defined( __BORLANDC__ )
#  include <iostream>
#else
#  include <istream.h>
#endif

#if ! defined( FG_HAVE_NATIVE_SGI_COMPILERS )
FG_USING_STD(istream);
#endif


class FGNav {

    char type;
    double lon, lat;
    double elev;
    double x, y, z;
    int freq;
    int range;
    bool has_dme;
    char ident[5];

public:

    inline FGNav(void) {}
    inline ~FGNav(void) {}

    inline char get_type() const { return type; }
    inline double get_lon() const { return lon; }
    inline double get_lat() const { return lat; }
    inline double get_elev() const { return elev; }
    inline double get_x() const { return x; }
    inline double get_y() const { return y; }
    inline double get_z() const { return z; }
    inline int get_freq() const { return freq; }
    inline int get_range() const { return range; }
    inline bool get_has_dme() const { return has_dme; }
    inline char *get_ident() { return ident; }

    /* inline void set_type( char t ) { type = t; }
    inline void set_lon( double l ) { lon = l; }
    inline void set_lat( double l ) { lat = l; }
    inline void set_elev( double e ) { elev = e; }
    inline void set_freq( int f ) { freq = f; }
    inline void set_range( int r ) { range = r; }
    inline void set_dme( bool b ) { dme = b; }
    inline void set_ident( char *i ) { strncpy( ident, i, 5 ); } */

    friend istream& operator>> ( istream&, FGNav& );
};


inline istream&
operator >> ( istream& in, FGNav& n )
{
    double f;
    char c;
    in >> n.type >> n.lat >> n.lon >> n.elev >> f >> n.range 
       >> c >> n.ident;

    n.freq = (int)(f*100.0 + 0.5);
    if ( c == 'Y' ) {
	n.has_dme = true;
    } else {
	n.has_dme = false;
    }

    // generate cartesian coordinates
    Point3D geod( n.lon * DEG_TO_RAD, n.lat * DEG_TO_RAD, n.elev );
    Point3D cart = fgGeodToCart( geod );
    n.x = cart.x();
    n.y = cart.y();
    n.z = cart.z();

    return in >> skipeol;
}


#endif // _FG_NAV_HXX
